@@ -27,28 +27,11 @@ sub fix_makefile {
     my $content = read_file($filename);
 
     my $add = q{
-
 print "Checking for GNU Scientific Library (GSL)...";
-
-my $libpath;
-
-eval {
-    $libpath = `pkg-config --libs gsl 2>/dev/null`;
+use lib 'inc';
+use Devel::CheckLib;
+check_lib_or_exit( lib => 'gsl' );
 };
-if (not $libpath) {
-    eval {
-        $libpath = `gsl-config --libs 2>/dev/null`;
-    }
-};
-
-if (not $libpath) {
-    die("I can't seem to find the GSL library (via pkg-config or gsl-config).\n"
-      . "Please install the GSL library (using your package manager,\n"
-      . "'cpanm Alien::GSL', or compile from source), and try again\n"
-    );
-}
-
-    };
 
     $content =~ s/^(use ExtUtils::MakeMaker[^\n]*)/$1\n$add/sm;
 
